@@ -1,7 +1,7 @@
 import shutil
 import tempfile
 import unittest
-import logging
+from numpy import vstack
 from pyspark import SparkContext
 
 
@@ -9,8 +9,9 @@ class PySparkTestCase(unittest.TestCase):
     def setUp(self):
         class_name = self.__class__.__name__
         self.sc = SparkContext('local', class_name)
-        logging.getLogger("py4j").setLevel(logging.WARNING)
-        logging.getLogger("py4j.java_gateway").setLevel(logging.WARNING)
+        self.sc._jvm.System.setProperty("spark.ui.showConsoleProgress", "false")
+        log4j = self.sc._jvm.org.apache.log4j
+        log4j.LogManager.getRootLogger().setLevel(log4j.Level.FATAL)
 
     def tearDown(self):
         self.sc.stop()
@@ -23,9 +24,30 @@ class PySparkTestCaseWithOutputDir(PySparkTestCase):
     def setUp(self):
         super(PySparkTestCaseWithOutputDir, self).setUp()
         self.outputdir = tempfile.mkdtemp()
-        logging.getLogger("py4j").setLevel(logging.WARNING)
-        logging.getLogger("py4j.java_gateway").setLevel(logging.WARNING)
 
     def tearDown(self):
         super(PySparkTestCaseWithOutputDir, self).tearDown()
-        shutil.rmtree(self.outputdir)
\ No newline at end of file
+        shutil.rmtree(self.outputdir)
+
+
+def elementwiseMean(arys):
+    from numpy import mean
+    combined = vstack([ary.ravel() for ary in arys])
+    meanAry = mean(combined, axis=0)
+    return meanAry.reshape(arys[0].shape)
+
+
+def elementwiseVar(arys):
+    from numpy import var
+    combined = vstack([ary.ravel() for ary in arys])
+    varAry = var(combined, axis=0)
+    return varAry.reshape(arys[0].shape)
+
+
+def elementwiseStdev(arys):
+    from numpy import std
+    combined = vstack([ary.ravel() for ary in arys])
+    stdAry = std(combined, axis=0)
+    return stdAry.reshape(arys[0].shape)
+
+
