@@ -36,7 +36,7 @@ class KMeansModel(object):
         centers = self.centers
 
         if isinstance(data, Series):
-            return data.apply(lambda x: func(centers, x))
+            return data.applyValues(lambda x: func(centers, x))
 
         elif isinstance(data, list):
             return map(lambda x: func(centers, x), data)
@@ -62,8 +62,8 @@ class KMeansModel(object):
             For each data point, ggives the closest center to that point
         """
         from scipy.spatial.distance import cdist
-        closestpoint = lambda centers, p: argmin(cdist(centers, array([p])))
-        out = self.calc(data, closestpoint)
+        closestPoint = lambda centers, p: argmin(cdist(centers, array([p])))
+        out = self.calc(data, closestPoint)
         if isinstance(data, Series):
             out._index = 'label'
         return out
@@ -92,7 +92,8 @@ class KMeansModel(object):
 
 
 class KMeans(object):
-    """KMeans clustering algorithm.
+    """
+    KMeans clustering algorithm.
 
     Parameters
     ----------
@@ -130,7 +131,7 @@ class KMeans(object):
 
         import pyspark.mllib.clustering as mllib
 
-        model = mllib.KMeans.train(data.rdd.values(), k=self.k, maxIterations=self.maxIterations)
+        model = mllib.KMeans.train(data.astype('float').rdd.values(), k=self.k, maxIterations=self.maxIterations)
 
         return KMeansModel(asarray(model.clusterCenters))
 
