@@ -45,13 +45,11 @@ class TiffParser(object):
         """
         self._fp = fp
         self._debug = debug
-        self.max_ifd_size = TiffParser.INIT_IFD_SIZE
+        self.maxIfdSize = TiffParser.INIT_IFD_SIZE
         self._order = None
-        #self.file_header = None
-        #self.ifds = []
         if self._debug:
             self.nseeks = 0
-            self.bytes_read = 0
+            self.bytesRead = 0
             self.nreads = 0
 
     def __seek(self, pos):
@@ -62,12 +60,12 @@ class TiffParser(object):
                 self.nseeks += 1
 
     def __read(self, size=-1):
-        curbuf = self._fp.read(size)
+        curBuf = self._fp.read(size)
         if self._debug:
             self.nreads += 1
-        if size >= 0 and len(curbuf) < size:
+        if size >= 0 and len(curBuf) < size:
             # print "incomplete read: requested %d bytes, got %d; retrying" % (size, len(curbuf))
-            size -= len(curbuf)
+            size -= len(curBuf)
             buf = ' '  # init loop
             while size > 0 and len(buf) > 0:
                 # keep reading while we're still getting data (no EOF) and still have data left to get
@@ -79,11 +77,11 @@ class TiffParser(object):
                 #         print "incomplete read: requested %d bytes, got 0 (EOF)" % size
                 if self._debug:
                     self.nreads += 1
-                curbuf += buf  # costly concatenation here...
+                curBuf += buf  # costly concatenation here...
                 size -= len(buf)
         if self._debug:
-            self.bytes_read += len(curbuf)
-        return curbuf
+            self.bytesRead += len(curBuf)
+        return curBuf
 
     @property
     def order(self):
@@ -91,80 +89,80 @@ class TiffParser(object):
         """
         return self._order
 
-    def parseFileHeader(self, destination_tiff=None):
+    def parseFileHeader(self, destinationTiff=None):
         """
         Reads the initial 8-byte file header from the wrapped file pointer.
 
         Parameters:
         -----------
-        destination_tiff: TiffData object, or None
-            If destination_tiff is not None, then the parsed file header will be attached to the passed destination_tiff
-            object as its file_header attribute, in addition to being returned from the method call.
+        destinationTiff: TiffData object, or None
+            If destinationTiff is not None, then the parsed file header will be attached to the passed destinationTiff
+            object as its fileHeader attribute, in addition to being returned from the method call.
 
         Returns:
         --------
         TiffFileHeader object
         """
         self.__seek(0)
-        header_buf = self.__read(8)
-        file_header = TiffFileHeader.fromBytes(header_buf)
-        self._order = file_header.byte_order
-        if destination_tiff:
-            destination_tiff.file_header = file_header
-        return file_header
+        headerBuf = self.__read(8)
+        fileHeader = TiffFileHeader.fromBytes(headerBuf)
+        self._order = fileHeader.byteOrder
+        if destinationTiff:
+            destinationTiff.fileHeader = fileHeader
+        return fileHeader
 
-    def parseNextImageFileDirectory(self, destination_tiff=None, ifd_offset=None):
+    def parseNextImageFileDirectory(self, destinationTiff=None, ifdOffset=None):
         """
         Reads the next Image File Directory in the wrapped file.
 
-        The offset of the next IFD within the file is determined either from the passed destination_tiff, or is passed
-        explicitly in ifd_offset. One or the other must be passed.
+        The offset of the next IFD within the file is determined either from the passed destinationTiff, or is passed
+        explicitly in ifdOffset. One or the other must be passed.
 
         Parameters:
         -----------
-        destination_tiff: TiffData object with a valid file_header attribute, or None
+        destinationTiff: TiffData object with a valid fileHeader attribute, or None
             If passed, the offset of the next IFD will be found either from the previous IFDs stored within
-            destination_tiff if any, or from destination_tiff.file_header if not. The parsed IFD will be added to
-            the destination_tiff.ifds sequence.
+            destinationTiff if any, or from destinationTiff.fileHeader if not. The parsed IFD will be added to
+            the destinationTiff.ifds sequence.
 
-        ifd_offset: positive integer offset within the wrapped file, or None
-            If destination_tiff is None and ifd_offset is passed, then ifd_offset will be used as the file offset
+        ifdOffset: positive integer offset within the wrapped file, or None
+            If destinationTiff is None and ifdOffset is passed, then ifdOffset will be used as the file offset
             at which to look for the next IFD.
 
         Returns:
         --------
         TiffImageFileDirectory object
         """
-        if (not destination_tiff) and (ifd_offset is None):
-            raise ValueError("Either destination_tiff or ifd_offset must be specified")
-        if destination_tiff:
-            offset = destination_tiff.ifds[-1].ifd_offset if destination_tiff.ifds else \
-                destination_tiff.file_header.ifd_offset
+        if (not destinationTiff) and (ifdOffset is None):
+            raise ValueError("Either destinationTiff or ifdOffset must be specified")
+        if destinationTiff:
+            offset = destinationTiff.ifds[-1].ifdOffset if destinationTiff.ifds else \
+                destinationTiff.fileHeader.ifdOffset
             if not offset:
                 return None
         else:
-            offset = ifd_offset
+            offset = ifdOffset
 
         # read out our current best guess at the IFD size for this file in bytes:
         self.__seek(offset)
-        ifd_buf = self.__read(self.max_ifd_size)
+        ifdBuf = self.__read(self.maxIfdSize)
         # check whether we actually got enough:
-        reqd_buf_size = TiffImageFileDirectory.parseIFDBufferSize(ifd_buf, self.order)
-        if reqd_buf_size > self.max_ifd_size:
-            self.max_ifd_size = reqd_buf_size
-        if reqd_buf_size > len(ifd_buf):
+        reqdBufSize = TiffImageFileDirectory.parseIFDBufferSize(ifdBuf, self.order)
+        if reqdBufSize > self.maxIfdSize:
+            self.maxIfdSize = reqdBufSize
+        if reqdBufSize > len(ifdBuf):
             # we hope we get the full buffer on the second attempt
-            ifd_buf = self.__read(reqd_buf_size)
-            if len(ifd_buf) < reqd_buf_size:
+            ifdBuf = self.__read(reqdBufSize)
+            if len(ifdBuf) < reqdBufSize:
                 raise IOError("Unable to read all %d bytes of tiff image file directory; got only %d bytes" %
-                              (reqd_buf_size, len(ifd_buf)))
+                              (reqdBufSize, len(ifdBuf)))
 
-        ifd = TiffImageFileDirectory.fromBytes(ifd_buf, self.order)
-        if destination_tiff:
-            destination_tiff.ifds.append(ifd)
+        ifd = TiffImageFileDirectory.fromBytes(ifdBuf, self.order)
+        if destinationTiff:
+            destinationTiff.ifds.append(ifd)
         return ifd
 
-    def getOffsetDataForIFD(self, ifd, max_buf=10**6, max_gap=1024):
+    def getOffsetDataForIFD(self, ifd, maxBuf=10**6, maxGap=1024):
         """Loads TIF tag offset and image data for the page described in the passed IFD.
 
         This method will typically be called from packSinglePage() rather than being used directly by clients.
@@ -173,102 +171,100 @@ class TiffParser(object):
         -----------
         ifd: TiffImageFileDirectory
 
-        max_buf: positive integer, default 10^6 (1MB)
+        maxBuf: positive integer, default 10^6 (1MB)
             Requests a largest size to use for file reads. Multiple contiguous image strips (or other data) of less
-            than max_buf in size will be read in a single read() call. If a single strip is larger than max_buf, then
+            than maxBuf in size will be read in a single read() call. If a single strip is larger than maxBuf, then
             it will still be read, in a single read call requesting exactly the strip size.
 
-        max_gap: positive integer, default 1024 (1KB)
+        maxGap: positive integer, default 1024 (1KB)
             Specifies the largest gap in meaningful data to tolerate within a single read() call. If two items of offset
-            data for a single IFD are separated by more than max_gap of data not within the IFD, then they will be read
-            in multiple read() calls. If they are separated by max_gap or less, then a single read() will be used and
+            data for a single IFD are separated by more than maxGap of data not within the IFD, then they will be read
+            in multiple read() calls. If they are separated by maxGap or less, then a single read() will be used and
             the irrelevant data in between simply ignored.
 
         Returns:
         --------
         TiffIFDData
         """
-        return_data = TiffIFDData()
-        return_data.ifd = ifd
+        returnData = TiffIFDData()
+        returnData.ifd = ifd
 
-        startlengths = ifd.getOffsetStartsAndLengths()
-        buf_startlens = calcReadsForOffsets(startlengths, max_buf, max_gap)
+        startLengths = ifd.getOffsetStartsAndLengths()
+        bufStartLens = calcReadsForOffsets(startLengths, maxBuf, maxGap)
 
         buffers = []
-        for bs, bl in buf_startlens:
+        for bs, bl in bufStartLens:
             self.__seek(bs)
             buf = self.__read(bl)
             buffers.append(TiffBuffer(bs, buf))
 
         for entry in ifd.entries:
-            if entry.isoffset:
-                offset, val_length = entry.getOffsetStartAndLength()
+            if entry.isOffset:
+                offset, valLength = entry.getOffsetStartAndLength()
                 found = False
-                for tif_buff in buffers:
-                    if tif_buff.contains(offset, val_length):
-                        #print "Buffer at orig offset %d, length %d, contains offset data starting at %d, length %d" % \
-                        # (tif_buff.orig_offset, len(tif_buff.buffer), offset, val_length)
+                for tiffBuff in buffers:
+                    if tiffBuff.contains(offset, valLength):
                         found = True
                         fmt = self.order + entry.getOffsetDataFormat()
-                        vals = tif_buff.unpackFrom(fmt, offset)
-                        return_data.entries_and_offsetdata.append(
+                        vals = tiffBuff.unpackFrom(fmt, offset)
+                        returnData.entriesAndOffsetData.append(
                             TiffIFDEntryAndOffsetData(*(entry, vals)))
                         break
                 if not found:
                     raise ValueError("Offset data at start: %d length: %d not found in available buffers" %
-                                     (offset, val_length))
+                                     (offset, valLength))
             else:
-                return_data.entries_and_offsetdata.append(
+                returnData.entriesAndOffsetData.append(
                     TiffIFDEntryAndOffsetData(*(entry, None)))
 
         del buffers
-        image_offsets = None
-        image_bytesizes = None
-        for ifd_entry_and_data in return_data.entries_and_offsetdata:
-            if ifd_entry_and_data.entry.isImageDataOffsetEntry():
-                if image_offsets:
+        imageOffsets = None
+        imageBytesizes = None
+        for ifdEntryAndData in returnData.entriesAndOffsetData:
+            if ifdEntryAndData.entry.isImageDataOffsetEntry():
+                if imageOffsets:
                     raise TiffFormatError("Found duplicate image data offset entries in single IFD")
-                image_offsets = ifd_entry_and_data.getData()
-            elif ifd_entry_and_data.entry.isImageDataByteCountEntry():
-                if image_bytesizes:
+                imageOffsets = ifdEntryAndData.getData()
+            elif ifdEntryAndData.entry.isImageDataByteCountEntry():
+                if imageBytesizes:
                     raise TiffFormatError("Found duplicate image data byte size entries in single IFD")
-                image_bytesizes = ifd_entry_and_data.getData()
+                imageBytesizes = ifdEntryAndData.getData()
 
-        if (not image_offsets) or (not image_bytesizes):
+        if (not imageOffsets) or (not imageBytesizes):
             raise TiffFormatError("Missing image offset or byte size data in IFD")
-        if len(image_offsets) != len(image_bytesizes):
+        if len(imageOffsets) != len(imageBytesizes):
             raise TiffFormatError("Unequal numbers of image data offset and byte size entries in IFD " +
-                                  "(offsets: %d, byte sizes: %d" % (len(image_offsets), len(image_bytesizes)))
+                                  "(offsets: %d, byte sizes: %d" % (len(imageOffsets), len(imageBytesizes)))
 
-        startlengths = zip(image_offsets, image_bytesizes)
-        del image_offsets, image_bytesizes
-        buf_startlens = calcReadsForOffsets(startlengths, max_buf, max_gap)
+        startLengths = zip(imageOffsets, imageBytesizes)
+        del imageOffsets, imageBytesizes
+        bufStartLens = calcReadsForOffsets(startLengths, maxBuf, maxGap)
 
         buffers = []
-        for bs, bl in buf_startlens:
+        for bs, bl in bufStartLens:
             self.__seek(bs)
             buf = self.__read(bl)
             buffers.append(TiffBuffer(bs, buf))
 
         # validate that all data was read successfully and set up views
-        data_views = []
-        for st, l in startlengths:
+        dataViews = []
+        for st, l in startLengths:
             found = False
             for buf in buffers:
                 if buf.contains(st, l):
-                    #print "Buffer at orig offset %d, length %d, contains strip starting at %d, length %d" % \
+                    # print "Buffer at orig offset %d, length %d, contains strip starting at %d, length %d" % \
                     #      (buf.orig_offset, len(buf.buffer), st, l)
-                    data_views.append(buf.bufferFrom(st, l))
+                    dataViews.append(buf.bufferFrom(st, l))
                     found = True
                     break
             if not found:
                 raise TiffFormatError("Could not find buffer with data at offset: %d, size: %d" % (st, l))
 
-        return_data.imagedata_buffers = data_views
-        return return_data
+        returnData.imagedataBuffers = dataViews
+        return returnData
 
 
-def packSinglePage(parser, tiff_data=None, page_idx=0):
+def packSinglePage(parser, tiffData=None, pageIdx=0):
     """Creates a string buffer with valid tif file data from a single page of a multipage tif.
 
     The resulting string buffer can be written to disk as a TIF file or loaded directly by PIL or similar.
@@ -278,14 +274,14 @@ def packSinglePage(parser, tiff_data=None, page_idx=0):
     parser: TifParser object.
         The parser should be initialized with a file handle of the multipage tif from which a page is to be extracted.
 
-    tiff_data: TiffData object, or none.
-        If tiff_data is passed, the tif file header and IFDs will be read out from it. If an empty tiff_data object or
+    tiffData: TiffData object, or none.
+        If tiffData is passed, the tif file header and IFDs will be read out from it. If an empty tiffData object or
         one without all IFDs in place is passed, then the file header and remaining required IFDs will be placed into
-        it. If tiff_data is None, a new TiffData object will be generated internally to the function and discarded when
-        the functional call completes. Passing tiff_data basically amounts to an optimization, to prevent rereading
+        it. If tiffData is None, a new TiffData object will be generated internally to the function and discarded when
+        the functional call completes. Passing tiffData basically amounts to an optimization, to prevent rereading
         data that presumably has already been parsed out from the file.
 
-    page_idx: nonnegative integer page number
+    pageIdx: nonnegative integer page number
         Specifies the zero-based page number to be read out and repacked from the multipage tif wrapped by the passed
         parser object.
 
@@ -293,74 +289,73 @@ def packSinglePage(parser, tiff_data=None, page_idx=0):
     --------
     string of bytes, making up a valid single-page TIF file.
     """
-    if not tiff_data:
-        tiff_data = TiffData()
-    if not tiff_data.file_header:
-        parser.parseFileHeader(destination_tiff=tiff_data)
-    while len(tiff_data.ifds) <= page_idx:
-        parser.parseNextImageFileDirectory(destination_tiff=tiff_data)
+    if not tiffData:
+        tiffData = TiffData()
+    if not tiffData.fileHeader:
+        parser.parseFileHeader(destinationTiff=tiffData)
+    while len(tiffData.ifds) <= pageIdx:
+        parser.parseNextImageFileDirectory(destinationTiff=tiffData)
 
-    tif_ifd_data = parser.getOffsetDataForIFD(tiff_data.ifds[page_idx])
+    tiffIfdData = parser.getOffsetDataForIFD(tiffData.ifds[pageIdx])
     order = parser.order
 
-    preamble = TiffFileHeader.new(order, tiff_data.file_header.byteSize())
-    buf_size = preamble.byteSize() + tif_ifd_data.byteSize()
+    preamble = TiffFileHeader.new(order, tiffData.fileHeader.byteSize())
+    bufSize = preamble.byteSize() + tiffIfdData.byteSize()
 
-    out_buffer = ctypes.create_string_buffer(buf_size)
-    offset = preamble.toBytes(out_buffer, 0)
-    ifd_size = tif_ifd_data.ifd.byteSize()
-    ifd_data_offset = offset + ifd_size
-    img_data_offset = ifd_data_offset + tif_ifd_data.ifd.getTotalOffsetSize()
+    outBuffer = ctypes.create_string_buffer(bufSize)
+    offset = preamble.toBytes(outBuffer, 0)
+    ifdSize = tiffIfdData.ifd.byteSize()
+    ifdDataOffset = offset + ifdSize
+    imgDataOffset = ifdDataOffset + tiffIfdData.ifd.getTotalOffsetSize()
     # write IFD
-    offset += tif_ifd_data.ifd.toBytes(ifd_data_offset, img_data_offset, out_buffer,
-                                       dest_offset=offset, order=order)
+    offset += tiffIfdData.ifd.toBytes(ifdDataOffset, imgDataOffset, outBuffer,
+                                      destOffset=offset, order=order)
     # write offset IFD values
-    for entry, value in tif_ifd_data.entries_and_offsetdata:
-        if entry.isoffset:
+    for entry, value in tiffIfdData.entriesAndOffsetdata:
+        if entry.isOffset:
             fmt = order + entry.getOffsetDataFormat()
             l = struct.calcsize(fmt)
             if entry.isImageDataOffsetEntry():
                 # reset image data offsets
-                min_orig_offset = reduce(min, value)
-                value = [v - min_orig_offset + img_data_offset for v in value]
-            struct.pack_into(fmt, out_buffer, offset, *value)
+                minOrigOffset = reduce(min, value)
+                value = [v - minOrigOffset + imgDataOffset for v in value]
+            struct.pack_into(fmt, outBuffer, offset, *value)
             offset += l
     # write image data values
     # assert offset == img_data_offset
-    for img_buf in tif_ifd_data.imagedata_buffers:
-        out_buffer[offset:(offset+len(img_buf))] = img_buf
-        offset += len(img_buf)
-    return out_buffer.raw
+    for imgBuf in tiffIfdData.imagedataBuffers:
+        outBuffer[offset:(offset+len(imgBuf))] = imgBuf
+        offset += len(imgBuf)
+    return outBuffer.raw
 
 
 class TiffBuffer(object):
     """Utility object to hold results of file read() calls.
     """
-    def __init__(self, orig_offset, buffer_):
-        self.orig_offset = orig_offset
+    def __init__(self, origOffset, buffer_):
+        self.origOffset = origOffset
         self.buffer = buffer_
-        self.buffer_len = len(buffer_)
+        self.bufferLen = len(buffer_)
 
     def contains(self, offset, length):
         lbuf = len(self.buffer)
-        start_inbounds = offset >= self.orig_offset
-        end_inbounds = offset + length <= self.orig_offset + lbuf
-        return start_inbounds and end_inbounds
-        #return offset >= self.orig_offset and length <= len(self.buffer)
+        startInbounds = offset >= self.origOffset
+        endInbounds = offset + length <= self.origOffset + lbuf
+        return startInbounds and endInbounds
 
-    def unpackFrom(self, fmt, orig_offset):
+    def unpackFrom(self, fmt, origOffset):
         """Deserializes data within this buffer according to the passed format, which will be interpreted by the
         python struct package.
 
         Returns tuple of values. (May be a one-tuple.)
         """
-        return struct.unpack_from(fmt, self.buffer, offset=orig_offset-self.orig_offset)
+        return struct.unpack_from(fmt, self.buffer, offset=origOffset-self.origOffset)
 
-    def bufferFrom(self, orig_offset, size=-1):
+    def bufferFrom(self, origOffset, size=-1):
         if size < 0:
-            return buffer(self.buffer, orig_offset-self.orig_offset)
+            return buffer(self.buffer, origOffset-self.origOffset)
         else:
-            return buffer(self.buffer, orig_offset-self.orig_offset, size)
+            return buffer(self.buffer, origOffset-self.origOffset, size)
 
 
 class TiffData(object):
@@ -370,7 +365,7 @@ class TiffData(object):
     hold tag offset data or image data.
     """
     def __init__(self):
-        self.file_header = None
+        self.fileHeader = None
         self.ifds = []
 
 
@@ -379,15 +374,15 @@ class TiffIFDData(object):
     """
     def __init__(self):
         self.ifd = None
-        self.entries_and_offsetdata = []
-        self.imagedata_buffers = []
+        self.entriesAndOffsetData = []
+        self.imagedataBuffers = []
 
     def byteSize(self):
-        imgdat_size = sum(len(buf) for buf in self.imagedata_buffers)
-        return self.ifd.byteSize() + self.ifd.getTotalOffsetSize() + imgdat_size
+        imgdatSize = sum(len(buf) for buf in self.imagedataBuffers)
+        return self.ifd.byteSize() + self.ifd.getTotalOffsetSize() + imgdatSize
 
 
-class TiffFileHeader(namedtuple('_TiffFileHeader', 'byte_order magic ifd_offset')):
+class TiffFileHeader(namedtuple('_TiffFileHeader', 'byteOrder magic ifdOffset')):
     """Data structure representing the 8-byte header found at the beginning of a tiff file.
     """
     @classmethod
@@ -406,10 +401,10 @@ class TiffFileHeader(namedtuple('_TiffFileHeader', 'byte_order magic ifd_offset'
             raise TiffFormatError("Found bad magic number %d, should be 42" % magic)
         return cls(code, magic, offset)
 
-    def toBytes(self, dest_buf, dest_offset=0):
-        order_flag = "II" if self.byte_order == '<' else "MM"
-        dest_buf[dest_offset:(dest_offset+2)] = order_flag
-        struct.pack_into(self.byte_order+"HI", dest_buf, dest_offset+2, self.magic, self.ifd_offset)
+    def toBytes(self, destBuf, destOffset=0):
+        orderFlag = "II" if self.byteOrder == '<' else "MM"
+        destBuf[destOffset:(destOffset+2)] = orderFlag
+        struct.pack_into(self.byteOrder+"HI", destBuf, destOffset+2, self.magic, self.ifdOffset)
         return self.byteSize()
 
     def asBytes(self):
@@ -424,7 +419,7 @@ class TiffFileHeader(namedtuple('_TiffFileHeader', 'byte_order magic ifd_offset'
     def new(cls, order="=", offset=8):
         if order in ("=", "@"):
             order = ">" if sys.byteorder == "big" else "<"
-        if not order in (">", "<"):
+        if order not in (">", "<"):
             raise ValueError("Order must be '>' or '<' for big or little-endian respectively; got '%s'" % order)
         return cls(order, 42, offset)
 
@@ -437,7 +432,7 @@ class TiffImageFileDirectory(object):
     Individual IFD entries are represented within the 'entries' sequence attribute, which holds multiple
     TiffIFDEntry objects.
     """
-    __slots__ = ('num_entries', 'entries', 'ifd_offset', 'order')
+    __slots__ = ('numEntries', 'entries', 'ifdOffset', 'order')
 
     @classmethod
     def parseIFDBufferSize(cls, buf, order, offset=0):
@@ -451,20 +446,20 @@ class TiffImageFileDirectory(object):
     def fromBytes(cls, buf, order, offset=0):
         ifd = TiffImageFileDirectory()
         ifd.order = order
-        ifd.num_entries = struct.unpack_from(order+"H", buf, offset)[0]
-        ifd.ifd_offset = struct.unpack_from(order+"I", buf, offset + 2 + 12*ifd.num_entries)[0]
-        for ientry in xrange(ifd.num_entries):
+        ifd.numEntries = struct.unpack_from(order+"H", buf, offset)[0]
+        ifd.ifdOffset = struct.unpack_from(order+"I", buf, offset + 2 + 12*ifd.numEntries)[0]
+        for ientry in xrange(ifd.numEntries):
             ifd.entries.append(TiffIFDEntry.fromBytes(buf, order, offset + 2 + 12*ientry))
         return ifd
 
     def __init__(self):
-        self.num_entries = 0
+        self.numEntries = 0
         self.entries = []
-        self.ifd_offset = 0
+        self.ifdOffset = 0
         self.order = '='
 
     def byteSize(self):
-        return 6+12*self.num_entries
+        return 6+12*self.numEntries
 
     def getEntryValue(self, tag):
         """
@@ -477,7 +472,7 @@ class TiffImageFileDirectory(object):
             # could optimize this by exiting early if entry.tag > tag, because entries should be in sorted order
             # according to the TIFF spec, but I'm not sure it's worth it.
             if entry.tag == tag:
-                if entry.isoffset:
+                if entry.isOffset:
                     raise TiffFormatError("Tag %d is present, but is stored at offset %d rather than within IFD" %
                                           (tag, entry.val))
                 return entry.val
@@ -494,20 +489,20 @@ class TiffImageFileDirectory(object):
 
     def getSampleFormat(self):
         try:
-            sample_format = self.getEntryValue(SAMPLE_FORMAT_TAG)
+            sampleFormat = self.getEntryValue(SAMPLE_FORMAT_TAG)
         except KeyError:
             # default according to tif spec is UINT
-            sample_format = SAMPLE_FORMAT_UINT
-        return sample_format
+            sampleFormat = SAMPLE_FORMAT_UINT
+        return sampleFormat
 
     def getOffsetStartsAndLengths(self):
-        startlengths = [entry.getOffsetStartAndLength() for entry in self.entries]
-        startlengths = filter(None, startlengths)
-        return startlengths
+        startLengths = [entry.getOffsetStartAndLength() for entry in self.entries]
+        startLengths = filter(None, startLengths)
+        return startLengths
 
     def getTotalOffsetSize(self):
-        startlengths = self.getOffsetStartsAndLengths()
-        return sum(sl[1] for sl in startlengths)
+        startLengths = self.getOffsetStartsAndLengths()
+        return sum(sl[1] for sl in startLengths)
 
     def hasEntry(self, tag):
         found = False
@@ -520,39 +515,39 @@ class TiffImageFileDirectory(object):
     def isLuminanceImage(self):
         try:
             interp = self.getEntryValue(PHOTOMETRIC_INTERPRETATION_TAG)
-            interp_ok = interp == 0 or interp == 1  # min is white or min is black
+            interpOk = interp == 0 or interp == 1  # min is white or min is black
         except IndexError:
             # if we are missing the photometric interpretation tag, even though technically it's required,
             # check that samples per pixel is either absent or 1
-            interp_ok = (not self.hasEntry(SAMPLES_PER_PIXEL_TAG)) or (self.getEntryValue(SAMPLES_PER_PIXEL_TAG) == 1)
-        return interp_ok
+            interpOk = (not self.hasEntry(SAMPLES_PER_PIXEL_TAG)) or (self.getEntryValue(SAMPLES_PER_PIXEL_TAG) == 1)
+        return interpOk
 
     def __str__(self):
         entries = [str(entry) for entry in self.entries]
         return "Image File Directory\nnumber fields: %d\n%s\nnext IFD offset: %d" % \
-               (self.num_entries, '\n'.join(entries), self.ifd_offset)
+               (self.numEntries, '\n'.join(entries), self.ifdOffset)
 
-    def toBytes(self, new_offset, img_data_offset, dest_buf, dest_offset=0, order="="):
-        orig_dest_offset = dest_offset
-        struct.pack_into(order+"H", dest_buf, dest_offset, self.num_entries)
-        dest_offset += 2
+    def toBytes(self, newOffset, imgDataOffset, destBuf, destOffset=0, order="="):
+        origDestOffset = destOffset
+        struct.pack_into(order+"H", destBuf, destOffset, self.numEntries)
+        destOffset += 2
         for entry in self.entries:
-            if entry.isoffset:
+            if entry.isOffset:
                 st, l = entry.getOffsetStartAndLength()
-                dest_offset += entry.toBytes(dest_buf, new_offset=new_offset,
-                                             img_data_offset=img_data_offset,
-                                             dest_offset=dest_offset, order=order)
-                new_offset += l
+                destOffset += entry.toBytes(destBuf, newOffset=newOffset,
+                                            imgDataOffset=imgDataOffset,
+                                            destOffset=destOffset, order=order)
+                newOffset += l
             else:
-                dest_offset += entry.toBytes(dest_buf, img_data_offset=img_data_offset,
-                                             dest_offset=dest_offset, order=order)
+                destOffset += entry.toBytes(destBuf, imgDataOffset=imgDataOffset,
+                                            destOffset=destOffset, order=order)
         # write "last IFD" marker:
-        struct.pack_into(order+"I", dest_buf, dest_offset, 0)
-        dest_offset += 4
-        return dest_offset - orig_dest_offset
+        struct.pack_into(order+"I", destBuf, destOffset, 0)
+        destOffset += 4
+        return destOffset - origDestOffset
 
 
-class TiffIFDEntry(namedtuple('_TiffIFDEntry', 'tag type count val isoffset')):
+class TiffIFDEntry(namedtuple('_TiffIFDEntry', 'tag type count val isOffset')):
     """Data structure representing a single entry within a tif IFD.
 
     Data stored in an offset from the IFD table will not be explicitly represented in this object; only the file offset
@@ -563,37 +558,37 @@ class TiffIFDEntry(namedtuple('_TiffIFDEntry', 'tag type count val isoffset')):
         tag, type_, count = struct.unpack_from(order+'HHI', buf, offset)
         rawval = buf[(offset+8):(offset+12)]
 
-        tagtype = IFD_ENTRY_TYPECODE_TO_TAGTYPE[type_]
-        bytesize = count * tagtype.size
-        isoffset = bytesize > 4 or tagtype.type == 'UNK'
-        if not isoffset:
-            val = struct.unpack_from(order+tagtype.fmt*count, rawval)
+        tagType = IFD_ENTRY_TYPECODE_TO_TAGTYPE[type_]
+        bytesize = count * tagType.size
+        isOffset = bytesize > 4 or tagType.type == 'UNK'
+        if not isOffset:
+            val = struct.unpack_from(order+tagType.fmt*count, rawval)
             if count == 1:
                 val = val[0]
         else:
             val = struct.unpack(order+'I', rawval)[0]
-        return cls(tag, type_, count, val, isoffset)
+        return cls(tag, type_, count, val, isOffset)
 
-    def toBytes(self, dest_buf, new_offset=None, img_data_offset=None, dest_offset=0, order="="):
-        if new_offset is None and self.isoffset:
-            new_offset = self.val
+    def toBytes(self, destBuf, newOffset=None, imgDataOffset=None, destOffset=0, order="="):
+        if newOffset is None and self.isOffset:
+            newOffset = self.val
 
-        if self.isoffset:
-            val_fmt = 'L'
-            val = new_offset
-        elif self.isImageDataOffsetEntry() and img_data_offset:
+        if self.isOffset:
+            valFmt = 'L'
+            val = newOffset
+        elif self.isImageDataOffsetEntry() and imgDataOffset:
             # we are writing image data offsets within this entry; they are not themselves offset
             # for this to not be offset, there must be only one, since it's a long
-            val_fmt = 'L'
-            val = img_data_offset
+            valFmt = 'L'
+            val = imgDataOffset
         else:
-            val_fmt = lookup_tagtype(self.type).fmt * self.count
+            valFmt = lookupTagType(self.type).fmt * self.count
             val = self.val
 
-        fmt = order+"HHI"+val_fmt
-        fmt_size = struct.calcsize(fmt)
-        if fmt_size < 12:
-            fmt += 'x'*(12-fmt_size)
+        fmt = order+"HHI"+valFmt
+        fmtSize = struct.calcsize(fmt)
+        if fmtSize < 12:
+            fmt += 'x'*(12-fmtSize)
 
         packing = [self.tag, self.type, self.count]
         if isinstance(val, tuple):
@@ -601,22 +596,22 @@ class TiffIFDEntry(namedtuple('_TiffIFDEntry', 'tag type count val isoffset')):
         else:
             packing.append(val)
 
-        struct.pack_into(fmt, dest_buf, dest_offset, *packing)
+        struct.pack_into(fmt, destBuf, destOffset, *packing)
         return 12
 
-    def asBytes(self, new_offset=None, img_data_offset=None, order="="):
+    def asBytes(self, newOffset=None, imgDataOffset=None, order="="):
         buf = ctypes.create_string_buffer(self.byteSize())
-        self.toBytes(buf, new_offset=new_offset, img_data_offset=img_data_offset, dest_offset=0, order=order)
+        self.toBytes(buf, newOffset=newOffset, imgDataOffset=imgDataOffset, destOffset=0, order=order)
         return buf.raw
 
     def byteSize(self):
         return 12
 
     def getOffsetStartAndLength(self):
-        if not self.isoffset:
+        if not self.isOffset:
             return None
-        tagtype = IFD_ENTRY_TYPECODE_TO_TAGTYPE[self.type].fmt
-        l = struct.calcsize("=" + tagtype * self.count)
+        tagType = IFD_ENTRY_TYPECODE_TO_TAGTYPE[self.type].fmt
+        l = struct.calcsize("=" + tagType * self.count)
         return self.val, l
 
     def getOffsetDataFormat(self):
@@ -629,18 +624,18 @@ class TiffIFDEntry(namedtuple('_TiffIFDEntry', 'tag type count val isoffset')):
         return self.tag in IMAGE_DATA_BYTECOUNT_TAGS
 
     def __str__(self):
-        tagname = TAG_TO_NAME.get(self.tag, 'UNK')
-        typename = lookup_tagtype(self.type).type
+        tagName = TAG_TO_NAME.get(self.tag, 'UNK')
+        typeName = lookupTagType(self.type).type
         return "TiffIFDEntry(tag: %s (%d), type: %s (%d), count=%d, val=%s%s)" % \
-               (tagname, self.tag, typename, self.type, self.count, self.val,
-                ' (offset)' if self.isoffset else '')
+               (tagName, self.tag, typeName, self.type, self.count, self.val,
+                ' (offset)' if self.isOffset else '')
 
 
-class TiffIFDEntryAndOffsetData(namedtuple("_TiffIFDEntryAndOffsetData", "entry offset_data")):
+class TiffIFDEntryAndOffsetData(namedtuple("_TiffIFDEntryAndOffsetData", "entry offsetData")):
     """Simple pair structure to hold a TiffIFDEntry and its associated offset data, if any.
 
-    If offset data is present (entry.isoffset is True), then it will be stored in offset_data as a tuple. If no
-    offset data is present, then offset_data will be None.
+    If offset data is present (entry.isoffset is True), then it will be stored in offsetData as a tuple. If no
+    offset data is present, then offsetData will be None.
     """
     def getData(self):
         """Returns tuple of data from offset if present, otherwise from entry
@@ -648,18 +643,18 @@ class TiffIFDEntryAndOffsetData(namedtuple("_TiffIFDEntryAndOffsetData", "entry
         def tuplify(val):
             if isinstance(val, (tuple, list)):
                 return tuple(val)
-            return (val,)
+            return (val, )
 
-        if self.entry.isoffset:
-            return tuplify(self.offset_data)
+        if self.entry.isOffset:
+            return tuplify(self.offsetData)
         return tuplify(self.entry.val)
 
 
-def lookup_tagtype(typecode):
+def lookupTagType(typecode):
     return IFD_ENTRY_TYPECODE_TO_TAGTYPE.get(typecode, UNKNOWN_TAGTYPE)
 
 
-def calcReadsForOffsets(startLengthPairs, max_buf=10**6, max_gap=1024):
+def calcReadsForOffsets(startLengthPairs, maxBuf=10**6, maxGap=1024):
     """Plans a sequence of file reads and seeks to cover all the spans of data in startLengthPairs.
 
     Parameters:
@@ -667,15 +662,15 @@ def calcReadsForOffsets(startLengthPairs, max_buf=10**6, max_gap=1024):
     startLengthPairs: sequence of (int start, int length) pairs
         start is the offset position of an item of data, length is its size in bytes.
 
-    max_buf: positive integer, default 10^6 (1MB)
+    maxBuf: positive integer, default 10^6 (1MB)
             Requests a largest size to use for file reads. Multiple contiguous image strips (or other data) of less
-            than max_buf in size will be read in a single read() call. If a single strip is larger than max_buf, then
+            than maxBuf in size will be read in a single read() call. If a single strip is larger than maxBuf, then
             it will still be read, in a single read call requesting exactly the strip size.
 
-    max_gap: positive integer, default 1024 (1KB)
+    maxGap: positive integer, default 1024 (1KB)
             Specifies the largest gap in meaningful data to tolerate within a single read() call. If two items of offset
-            data for a single IFD are separated by more than max_gap of data not within the IFD, then they will be read
-            in multiple read() calls. If they are separated by max_gap or less, then a single read() will be used and
+            data for a single IFD are separated by more than maxGap of data not within the IFD, then they will be read
+            in multiple read() calls. If they are separated by maxGap or less, then a single read() will be used and
             the irrelevant data in between simply ignored.
 
     Returns:
@@ -687,24 +682,24 @@ def calcReadsForOffsets(startLengthPairs, max_buf=10**6, max_gap=1024):
     # we assume here that starts and offsets and generally sane - meaning (roughly) nonoverlapping
     if not startLengthPairs:
         return []
-    startlengths = sorted(startLengthPairs, key=operator.itemgetter(0))
+    startLengths = sorted(startLengthPairs, key=operator.itemgetter(0))
 
-    bufstarts = []
-    buflens = []
-    curstart, curlen = startlengths.pop(0)
-    for start, length in startlengths:
-        gap = start - (curstart + curlen)
-        newlen = start + length - curstart
-        if gap > max_gap or newlen > max_buf:
-            bufstarts.append(curstart)
-            buflens.append(curlen)
-            curstart = start
-            curlen = length
+    bufStarts = []
+    bufLens = []
+    curStart, curLen = startLengths.pop(0)
+    for start, length in startLengths:
+        gap = start - (curStart + curLen)
+        newLen = start + length - curStart
+        if gap > maxGap or newLen > maxBuf:
+            bufStarts.append(curStart)
+            bufLens.append(curLen)
+            curStart = start
+            curLen = length
         else:
-            curlen = newlen
-    bufstarts.append(curstart)
-    buflens.append(curlen)
-    return zip(bufstarts, buflens)
+            curLen = newLen
+    bufStarts.append(curStart)
+    bufLens.append(curLen)
+    return zip(bufStarts, bufLens)
 
 TiffTagType = namedtuple('TiffTagType', 'code type fmt size')
 
