@@ -169,6 +169,8 @@ def install_anaconda(master, opts):
     ssh(master, opts, "rm -rf /root/anaconda && bash Anaconda-2.1.0-Linux-x86_64.sh -b "
                       "&& rm Anaconda-2.1.0-Linux-x86_64.sh")
     ssh(master, opts, "echo 'export PATH=/root/anaconda/bin:$PATH:/root/spark/bin' >> /root/.bash_profile")
+    ssh(master, opts, "pssh -h /root/spark-ec2/slaves 'echo 'export "
+                      "PATH=/root/anaconda/bin:$PATH:/root/spark/bin' >> /root/.bash_profile'")
     print_success()
 
     # update core libraries
@@ -177,6 +179,9 @@ def install_anaconda(master, opts):
     ssh(master, opts, "/root/anaconda/bin/conda install --yes jsonschema pillow seaborn scikit-learn")
     print_success()
 
+    # add mistune (for notebook conversions)
+    ssh(master, opts, "source ~/.bash_profile && pip install mistune")
+
     # copy to slaves
     print_status("Copying Anaconda to workers")
     ssh(master, opts, "/root/spark-ec2/copy-dir /root/anaconda")
@@ -201,6 +206,9 @@ def install_thunder(master, opts):
     ssh(master, opts, "pssh -h /root/spark-ec2/slaves mkdir -p /root/thunder/python/thunder/utils/data/")
     ssh(master, opts, "~/spark-ec2/copy-dir /root/thunder/python/thunder/utils/data/")
 
+    # install requirements
+    ssh(master, opts, "source ~/.bash_profile && pip install -r /root/thunder/python/requirements.txt")
+
     # set environmental variables
     ssh(master, opts, "echo 'export SPARK_HOME=/root/spark' >> /root/.bash_profile")
     ssh(master, opts, "echo 'export PYTHONPATH=/root/thunder/python' >> /root/.bash_profile")
@@ -443,7 +451,15 @@ if __name__ == "__main__":
         parser.add_option("--placement-group", type="string", default=None,
                           help="Which placement group to try and launch instances into. Assumes placement "
                                "group is already created.")
+    parser.add_option("--spark-ec2-git-repo", default="https://github.com/mesos/spark-ec2",
+                      help="Github repo from which to checkout spark-ec2 (default: %default)")
+    parser.add_option("--spark-ec2-git-branch", default="branch-1.3",
+                      help="Github repo branch of spark-ec2 to use (default: %default)")
+    parser.add_option("--private-ips", action="store_true", default=False,
+                      help="Use private IPs for instances rather than public if VPC/subnet " +
+                      "requires that.")
 
+    
     (opts, args) = parser.parse_args()
     if len(args) != 2:
         parser.print_help()
